==> zio-aws-s3_2.12-5.19.7.5-sources.jar: zio/aws/s3/model/GetBucketAnalyticsConfigurationRequest.scala <==
package zio.aws.s3.model
import zio.aws.s3.model.primitives.{AccountId, AnalyticsId, BucketName}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class GetBucketAnalyticsConfigurationRequest(
    bucket: BucketName,
    id: AnalyticsId,
    expectedBucketOwner: Optional[AccountId] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.s3.model.GetBucketAnalyticsConfigurationRequest = {
    import GetBucketAnalyticsConfigurationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.s3.model.GetBucketAnalyticsConfigurationRequest
      .builder()
      .bucket(BucketName.unwrap(bucket): java.lang.String)
      .id(AnalyticsId.unwrap(id): java.lang.String)
      .optionallyWith(
        expectedBucketOwner.map(value =>
          AccountId.unwrap(value): java.lang.String
        )
      )(_.expectedBucketOwner)
      .build()
  }
  def asReadOnly
      : zio.aws.s3.model.GetBucketAnalyticsConfigurationRequest.ReadOnly =
    zio.aws.s3.model.GetBucketAnalyticsConfigurationRequest
      .wrap(buildAwsValue())
}
object GetBucketAnalyticsConfigurationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.s3.model.GetBucketAnalyticsConfigurationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.s3.model.GetBucketAnalyticsConfigurationRequest =
      zio.aws.s3.model.GetBucketAnalyticsConfigurationRequest(
        bucket,
        id,
        expectedBucketOwner.map(value => value)
      )
    def bucket: BucketName
    def id: AnalyticsId
    def expectedBucketOwner: Optional[AccountId]
    def getBucket: ZIO[Any, Nothing, BucketName] = ZIO.succeed(bucket)
    def getId: ZIO[Any, Nothing, AnalyticsId] = ZIO.succeed(id)
    def getExpectedBucketOwner: ZIO[Any, AwsError, AccountId] =
      AwsError.unwrapOptionField("expectedBucketOwner", expectedBucketOwner)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.s3.model.GetBucketAnalyticsConfigurationRequest
  ) extends zio.aws.s3.model.GetBucketAnalyticsConfigurationRequest.ReadOnly {
    override val bucket: BucketName =
      zio.aws.s3.model.primitives.BucketName(impl.bucket())
    override val id: AnalyticsId =
      zio.aws.s3.model.primitives.AnalyticsId(impl.id())
    override val expectedBucketOwner: Optional[AccountId] =
      zio.aws.core.internal
        .optionalFromNullable(impl.expectedBucketOwner())
        .map(value => zio.aws.s3.model.primitives.AccountId(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.s3.model.GetBucketAnalyticsConfigurationRequest
  ): zio.aws.s3.model.GetBucketAnalyticsConfigurationRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-s3_3-5.17.158.4-sources.jar: zio/aws/s3/model/GetBucketAnalyticsConfigurationRequest.scala <==
package zio.aws.s3.model
import zio.aws.s3.model.primitives.{AccountId, AnalyticsId, BucketName}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class GetBucketAnalyticsConfigurationRequest(
    bucket: BucketName,
    id: AnalyticsId,
    expectedBucketOwner: Option[AccountId] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.s3.model.GetBucketAnalyticsConfigurationRequest = {
    import GetBucketAnalyticsConfigurationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.s3.model.GetBucketAnalyticsConfigurationRequest
      .builder()
      .bucket(BucketName.unwrap(bucket): java.lang.String)
      .id(AnalyticsId.unwrap(id): java.lang.String)
      .optionallyWith(
        expectedBucketOwner.map(value =>
          AccountId.unwrap(value): java.lang.String
        )
      )(_.expectedBucketOwner)
      .build()
  }
  def asReadOnly
      : zio.aws.s3.model.GetBucketAnalyticsConfigurationRequest.ReadOnly =
    zio.aws.s3.model.GetBucketAnalyticsConfigurationRequest
      .wrap(buildAwsValue())
}
object GetBucketAnalyticsConfigurationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.s3.model.GetBucketAnalyticsConfigurationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.s3.model.GetBucketAnalyticsConfigurationRequest =
      zio.aws.s3.model.GetBucketAnalyticsConfigurationRequest(
        bucket,
        id,
        expectedBucketOwner.map(value => value)
      )
    def bucket: BucketName
    def id: AnalyticsId
    def expectedBucketOwner: Option[AccountId]
    def getBucket: ZIO[Any, Nothing, BucketName] = ZIO.succeed(bucket)
    def getId: ZIO[Any, Nothing, AnalyticsId] = ZIO.succeed(id)
    def getExpectedBucketOwner: ZIO[Any, AwsError, AccountId] =
      AwsError.unwrapOptionField("expectedBucketOwner", expectedBucketOwner)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.s3.model.GetBucketAnalyticsConfigurationRequest
  ) extends zio.aws.s3.model.GetBucketAnalyticsConfigurationRequest.ReadOnly {
    override val bucket: BucketName =
      zio.aws.s3.model.primitives.BucketName(impl.bucket())
    override val id: AnalyticsId =
      zio.aws.s3.model.primitives.AnalyticsId(impl.id())
    override val expectedBucketOwner: Option[AccountId] = scala
      .Option(impl.expectedBucketOwner())
      .map(value => zio.aws.s3.model.primitives.AccountId(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.s3.model.GetBucketAnalyticsConfigurationRequest
  ): zio.aws.s3.model.GetBucketAnalyticsConfigurationRequest.ReadOnly =
    new Wrapper(impl)
}
